@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import csv
-import os
 import platform
 import re
 import shutil
@@ -12,7 +11,6 @@ import zipfile
 
 from pathlib import Path
 from typing import TYPE_CHECKING
-from typing import Iterator
 
 import pytest
 
@@ -24,6 +22,8 @@ from tests.masonry.builders.test_wheel import WHEEL_TAG_REGEX
 
 
 if TYPE_CHECKING:
+    from collections.abc import Iterator
+
     from pytest_mock import MockerFixture
 
 fixtures_dir = Path(__file__).parent / "fixtures"
@@ -102,26 +102,26 @@ $""",
         assert len(set(record_files)) == len(record_files)
 
 
+@pytest.mark.parametrize("project", ["complete", "complete_new", "complete_dynamic"])
 @pytest.mark.parametrize("no_vcs", [False, True])
-def test_complete(no_vcs: bool) -> None:
-    module_path = fixtures_dir / "complete"
+def test_complete(project: str, no_vcs: bool) -> None:
+    module_path = fixtures_dir / project
 
     if no_vcs:
         # Copy the complete fixtures dir to a temporary directory
-        temporary_dir = Path(tempfile.mkdtemp()) / "complete"
+        temporary_dir = Path(tempfile.mkdtemp()) / project
         shutil.copytree(module_path.as_posix(), temporary_dir.as_posix())
         module_path = temporary_dir
 
     poetry = Factory().create_poetry(module_path)
-    with pytest.warns(DeprecationWarning, match=".* script .* extra"):
-        SdistBuilder(poetry).build()
-        WheelBuilder(poetry).build()
+    SdistBuilder(poetry).build()
+    WheelBuilder(poetry).build()
 
     whl = module_path / "dist" / "my_package-1.2.3-py3-none-any.whl"
 
     assert whl.exists()
     if sys.platform != "win32":
-        assert (os.stat(str(whl)).st_mode & 0o777) == 0o644
+        assert (whl.stat().st_mode & 0o777) == 0o644
 
     expected_name_list = [
         "my_package/__init__.py",
@@ -134,12 +134,12 @@ def test_complete(no_vcs: bool) -> None:
         *sorted(
             [
                 "my_package-1.2.3.dist-info/entry_points.txt",
-                "my_package-1.2.3.dist-info/LICENSE",
+                "my_package-1.2.3.dist-info/licenses/LICENSE",
                 "my_package-1.2.3.dist-info/METADATA",
                 "my_package-1.2.3.dist-info/WHEEL",
-                "my_package-1.2.3.dist-info/COPYING",
-                "my_package-1.2.3.dist-info/LICENCE",
-                "my_package-1.2.3.dist-info/AUTHORS",
+                "my_package-1.2.3.dist-info/licenses/COPYING",
+                "my_package-1.2.3.dist-info/licenses/LICENCE",
+                "my_package-1.2.3.dist-info/licenses/AUTHORS",
             ],
             key=lambda x: Path(x),
         ),
@@ -154,19 +154,21 @@ def test_complete(no_vcs: bool) -> None:
         )
 
         entry_points = zipf.read("my_package-1.2.3.dist-info/entry_points.txt")
-
         assert (
             entry_points.decode()
             == """\
 [console_scripts]
-extra-script=my_package.extra:main[time]
+extra-script=my_package.extra:main
 my-2nd-script=my_package:main2
 my-script=my_package:main
 
+[poetry.application.plugin]
+my-command=my_package.plugins:MyApplicationPlugin
+
 """
         )
-        wheel_data = zipf.read("my_package-1.2.3.dist-info/WHEEL").decode()
 
+        wheel_data = zipf.read("my_package-1.2.3.dist-info/WHEEL").decode()
         assert (
             wheel_data
             == f"""\
@@ -176,17 +178,18 @@ Root-Is-Purelib: true
 Tag: py3-none-any
 """
         )
-        wheel_data = zipf.read("my_package-1.2.3.dist-info/METADATA").decode()
 
-        assert (
-            wheel_data
-            == """\
-Metadata-Version: 2.1
+        metadata = zipf.read("my_package-1.2.3.dist-info/METADATA").decode()
+        expected_metadata = """\
+Metadata-Version: 2.4
 Name: my-package
 Version: 1.2.3
 Summary: Some description.
-Home-page: https://python-poetry.org/
 License: MIT
+License-File: AUTHORS
+License-File: COPYING
+License-File: LICENCE
+License-File: LICENSE
 Keywords: packaging,dependency,poetry
 Author: Sébastien Eustace
 Author-email: sebastien@eustace.io
@@ -202,6 +205,8 @@ Classifier: Programming Language :: Python :: 3.9
 Classifier: Programming Language :: Python :: 3.10
 Classifier: Programming Language :: Python :: 3.11
 Classifier: Programming Language :: Python :: 3.12
+Classifier: Programming Language :: Python :: 3.13
+Classifier: Programming Language :: Python :: 3.14
 Classifier: Topic :: Software Development :: Build Tools
 Classifier: Topic :: Software Development :: Libraries :: Python Modules
 Provides-Extra: time
@@ -210,6 +215,7 @@ Requires-Dist: cleo (>=0.6,<0.7)
 Requires-Dist: pendulum (>=1.4,<2.0) ; (python_version ~= "2.7"\
  and sys_platform == "win32" or python_version in "3.4 3.5") and (extra == "time")
 Project-URL: Documentation, https://python-poetry.org/docs
+Project-URL: Homepage, https://python-poetry.org/
 Project-URL: Issue Tracker, https://github.com/python-poetry/poetry/issues
 Project-URL: Repository, https://github.com/python-poetry/poetry
 Description-Content-Type: text/x-rst
@@ -218,7 +224,12 @@ My Package
 ==========
 
 """
-        )
+        if project == "complete_new":
+            expected_metadata = expected_metadata.replace(
+                "License:", "License-Expression:"
+            ).replace("Classifier: License :: OSI Approved :: MIT License\n", "")
+        assert metadata == expected_metadata
+
         actual_records = zipf.read("my_package-1.2.3.dist-info/RECORD").decode()
 
         # The SHA hashes vary per operating systems.
@@ -298,24 +309,10 @@ def test_package_with_include(mocker: MockerFixture) -> None:
     module_path = fixtures_dir / "with-include"
 
     # Patch git module to return specific excluded files
-    p = mocker.patch("poetry.core.vcs.git.Git.get_ignored_files")
-    p.return_value = [
-        str(
-            Path(__file__).parent
-            / "fixtures"
-            / "with-include"
-            / "extra_dir"
-            / "vcs_excluded.txt"
-        ),
-        str(
-            Path(__file__).parent
-            / "fixtures"
-            / "with-include"
-            / "extra_dir"
-            / "sub_pkg"
-            / "vcs_excluded.txt"
-        ),
-    ]
+    mocker.patch(
+        "poetry.core.vcs.git.Git.get_ignored_files",
+        return_value=["extra_dir/vcs_excluded.py", "extra_dir/sub_pkg/vcs_excluded.py"],
+    )
 
     poetry = Factory().create_poetry(module_path)
     SdistBuilder(poetry).build()
@@ -331,9 +328,9 @@ def test_package_with_include(mocker: MockerFixture) -> None:
         assert "with_include-1.2.3/LICENSE" in names
         assert "with_include-1.2.3/README.rst" in names
         assert "with_include-1.2.3/extra_dir/__init__.py" in names
-        assert "with_include-1.2.3/extra_dir/vcs_excluded.txt" in names
+        assert "with_include-1.2.3/extra_dir/vcs_excluded.py" in names
         assert "with_include-1.2.3/extra_dir/sub_pkg/__init__.py" in names
-        assert "with_include-1.2.3/extra_dir/sub_pkg/vcs_excluded.txt" not in names
+        assert "with_include-1.2.3/extra_dir/sub_pkg/vcs_excluded.py" not in names
         assert "with_include-1.2.3/my_module.py" in names
         assert "with_include-1.2.3/notes.txt" in names
         assert "with_include-1.2.3/package_with_include/__init__.py" in names
@@ -351,14 +348,14 @@ def test_package_with_include(mocker: MockerFixture) -> None:
     with zipfile.ZipFile(str(whl)) as z:
         names = z.namelist()
         assert len(names) == len(set(names))
-        assert "with_include-1.2.3.dist-info/LICENSE" in names
+        assert "with_include-1.2.3.dist-info/licenses/LICENSE" in names
         assert "extra_dir/__init__.py" in names
-        assert "extra_dir/vcs_excluded.txt" in names
+        assert "extra_dir/vcs_excluded.py" in names
         assert "extra_dir/sub_pkg/__init__.py" in names
-        assert "extra_dir/sub_pkg/vcs_excluded.txt" not in names
+        assert "extra_dir/sub_pkg/vcs_excluded.py" not in names
         assert "for_wheel_only/__init__.py" in names
         assert "my_module.py" in names
-        assert "notes.txt" in names
+        assert "notes.txt" not in names
         assert "package_with_include/__init__.py" in names
         assert "tests/__init__.py" not in names
         assert "src_package/__init__.py" in names
